==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/eu.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumentuak",
    "Can't create document" : "Ezin da dokumentua sortu",
    "You don't have permission to rename this document" : "Ez duzu dokumentu honi izena aldatzeko baimenik",
    "Directory saved successfully." : "Direktorioa ongi gorde da.",
    "An error occurred while changing directory." : "Errore bat gertatu da direktorioz aldatzen.",
    "Saved" : "Gordeta",
    "Format filter server is down or misconfigured" : "Formatuen iragazki zerbitzaria erorita edo gaizki konfiguratua",
    "Conversion failed. Check log for details." : "Bihurketak huts egin du. Begiratu erregistroak zehaztapenetarako.",
    "Saving..." : "Gordetzen...",
    "Failed to load documents." : "Dokumentuak kargatzeak huts egin du.",
    "No documents were found. Upload or create a document to get started!" : "Ez da dokumenturik aurkitu. Igo edo sortu dokumentu bat hasteko!",
    "No connection to server. Trying to reconnect." : "Ez dago konexiorik zerbitzariarekin. Birkonektatzen saiatzen.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Orri hau Editore moduan uzteak gordegabeko datuak utz ditzake. Aholkatzen da 'Itxi' botoia erabiltzea.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Dokumentu hau kargatzeak huts egin du. Mesedez egiaztatu ea kanpoko odt editore batekin ireki daitekeen. Honek ere dokumentua partekatzeari utzi egin zaiola edo ezabatu egin dela esan dezake.",
    "Save" : "Gorde",
    "Loading documents..." : "Dokumentuak kargatzen...",
    "'.' is an invalid file name." : "'.' ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "IZen aliogabea, '\\', '/', '<', '>', ':', '\"', '|', '?' eta '*' ez daude baimenduta.",
    "Align Left" : "Lerrokatu ezkerrean",
    "Alignment" : "Lerrokatzea",
    "Align Right" : "Lerrokatu eskuinean",
    "Annotate" : "Oharra idatzi",
    "Background" : "Atzeko planoa",
    "Bold" : "Lodia",
    "Bottom" : "Behean",
    "Cancel" : "Ezeztatu",
    "Center" : "Edrian",
    "Clone" : "Klonatu",
    "Clone this Style" : "Klonatu Estiloa",
    "Close" : "Itxi",
    "Color" : "Kolorea",
    "Create" : "Sortu",
    "Decrease Indent" : "Txikitu koxka",
    "Default Style" : "Estilo lehenetsia",
    "Delete" : "Ezabatu",
    "Family" : "Familia",
    "Font" : "Letra tipoa",
    "Font Effects" : "Letra efektuak",
    "Format" : "Formatua",
    "Increase Indent" : "Handitu koxka",
    "Insert Image" : "Txertatu irudia",
    "Invite Members" : "Gonbidatu partaideak",
    "Italic" : "Etzana",
    "Justified" : "Justifikatuta",
    "Justify" : "Justifikatu",
    "Left" : "Ezkerra",
    "Loading" : "Kargatzen",
    "Members" : "Partaideak",
    "New Name:" : "Izen berria",
    "OK" : "Ados",
    "Open" : "Ireki",
    "Options" : "Aukerak",
    "Paragraph..." : "Paragrafoa...",
    "Paragraph Styles" : "Paragrafo Estiloak",
    "Redo" : "Berregin",
    "Right" : "Eskuina",
    "Size" : "Tamaina",
    "Spacing" : "Tarteak",
    "Strikethrough" : "Marratuta",
    "Style" : "Estiloa",
    "Text" : "Testua",
    "Top" : "Goian",
    "Underline" : "Azpimarratua",
    "Undo" : "Desegin",
    "Unknown Author" : "Egile ezezaguna",
    "Edit" : "Editatu",
    "Share" : "Partekatu",
    "guest" : "gonbidatua",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word (openOffice/libreOffice behar du)",
    "Local" : "Bertakoa",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice zerbitzarian instalatuta dago. Programaren bidea preview_libreoffice_path aukeran zehaztu behar da config.php fitxategian",
    "External" : "Kanpokoa",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice kanpoko zerbitzari batean instalatuta dago zeinak formatu iragazki zerbitzari bat duen",
    "Disabled" : "Ez-gaitua",
    "No MS Word support" : "Ez da MS Word onartzen",
    "scheme://domain.tld[:port]" : "eskema://domain.tld[:port]",
    "Server URL" : "Zerbitzariaren URLa",
    "Apply and test" : "Aplikatu eta probatu",
    "New document" : "Dokumentu berria",
    "Upload (max. %s)" : "Igo (max. %s)",
    "Upload" : "Igo",
    "Save new documents to" : "Gorde dokumentu berriak hemen",
    "Wrong password. Please retry." : "Pasahitz okerra. Saiatu berriro.",
    "Password" : "Pasahitza",
    "Guest %s" : "Gonbidatua %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Lotura hau iraungi da edo ez da inoiz existitu. Mesedez zurekin partekatu zuen pertsonarekin harremanetan jarri zehaztasun gehiago izateko.",
    "Advanced feature-set" : "Ezaugarri aurreratu multzoa",
    "(Unstable)" : "(Ez-egonkorra)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/eu.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Dokumentuak",
    "Can't create document" : "Ezin da dokumentua sortu",
    "You don't have permission to rename this document" : "Ez duzu dokumentu honi izena aldatzeko baimenik",
    "Directory saved successfully." : "Direktorioa ongi gorde da.",
    "An error occurred while changing directory." : "Errore bat gertatu da direktorioz aldatzen.",
    "Saved" : "Gordeta",
    "Format filter server is down or misconfigured" : "Formatuen iragazki zerbitzaria erorita edo gaizki konfiguratua",
    "Conversion failed. Check log for details." : "Bihurketak huts egin du. Begiratu erregistroak zehaztapenetarako.",
    "Saving..." : "Gordetzen...",
    "Failed to load documents." : "Dokumentuak kargatzeak huts egin du.",
    "No documents were found. Upload or create a document to get started!" : "Ez da dokumenturik aurkitu. Igo edo sortu dokumentu bat hasteko!",
    "No connection to server. Trying to reconnect." : "Ez dago konexiorik zerbitzariarekin. Birkonektatzen saiatzen.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Orri hau Editore moduan uzteak gordegabeko datuak utz ditzake. Aholkatzen da 'Itxi' botoia erabiltzea.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Dokumentu hau kargatzeak huts egin du. Mesedez egiaztatu ea kanpoko odt editore batekin ireki daitekeen. Honek ere dokumentua partekatzeari utzi egin zaiola edo ezabatu egin dela esan dezake.",
    "Save" : "Gorde",
    "Loading documents..." : "Dokumentuak kargatzen...",
    "'.' is an invalid file name." : "'.' ez da fitxategi izen baliogarria.",
    "File name cannot be empty." : "Fitxategi izena ezin da hutsa izan.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "IZen aliogabea, '\\', '/', '<', '>', ':', '\"', '|', '?' eta '*' ez daude baimenduta.",
    "Align Left" : "Lerrokatu ezkerrean",
    "Alignment" : "Lerrokatzea",
    "Align Right" : "Lerrokatu eskuinean",
    "Annotate" : "Oharra idatzi",
    "Background" : "Atzeko planoa",
    "Bold" : "Lodia",
    "Bottom" : "Behean",
    "Cancel" : "Ezeztatu",
    "Center" : "Edrian",
    "Clone" : "Klonatu",
    "Clone this Style" : "Klonatu Estiloa",
    "Close" : "Itxi",
    "Color" : "Kolorea",
    "Create" : "Sortu",
    "Decrease Indent" : "Txikitu koxka",
    "Default Style" : "Estilo lehenetsia",
    "Delete" : "Ezabatu",
    "Family" : "Familia",
    "Font" : "Letra tipoa",
    "Font Effects" : "Letra efektuak",
    "Format" : "Formatua",
    "Increase Indent" : "Handitu koxka",
    "Insert Image" : "Txertatu irudia",
    "Invite Members" : "Gonbidatu partaideak",
    "Italic" : "Etzana",
    "Justified" : "Justifikatuta",
    "Justify" : "Justifikatu",
    "Left" : "Ezkerra",
    "Loading" : "Kargatzen",
    "Members" : "Partaideak",
    "New Name:" : "Izen berria",
    "OK" : "Ados",
    "Open" : "Ireki",
    "Options" : "Aukerak",
    "Paragraph..." : "Paragrafoa...",
    "Paragraph Styles" : "Paragrafo Estiloak",
    "Redo" : "Berregin",
    "Right" : "Eskuina",
    "Size" : "Tamaina",
    "Spacing" : "Tarteak",
    "Strikethrough" : "Marratuta",
    "Style" : "Estiloa",
    "Text" : "Testua",
    "Top" : "Goian",
    "Underline" : "Azpimarratua",
    "Undo" : "Desegin",
    "Unknown Author" : "Egile ezezaguna",
    "Shared" : "Elkarbanatuta",
    "Error" : "Errorea",
    "Error while sharing" : "Errore bat egon da elkarbanatzean",
    "Error while unsharing" : "Errore bat egon da elkarbanaketa desegitean",
    "Error while changing permissions" : "Errore bat egon da baimenak aldatzean",
    "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
    "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
    "Share" : "Partekatu",
    "Share link" : "Elkarbanatu lotura",
    "The public link will expire no later than {days} days after it is created" : "Esteka publikoak iraungi egingo du, askoz jota, sortu eta  {days} egunetara.",
    "Link" : "Esteka",
    "Password protect" : "Babestu pasahitzarekin",
    "Password" : "Pasahitza",
    "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
    "Allow editing" : "Baimendu editatzea",
    "Email link to person" : "Postaz bidali lotura ",
    "Send" : "Bidali",
    "Set expiration date" : "Ezarri muga data",
    "Expiration" : "Iraungitzea",
    "Expiration date" : "Muga data",
    "Adding user..." : "Erabiltzailea gehitzen...",
    "group" : "taldea",
    "remote" : "urrunekoa",
    "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
    "Shared in {item} with {user}" : "{user}ekin {item}-n elkarbanatuta",
    "Unshare" : "Ez elkarbanatu",
    "notify by email" : "jakinarazi eposta bidez",
    "can share" : "elkarbana dezake",
    "can edit" : "editatu dezake",
    "access control" : "sarrera kontrola",
    "create" : "sortu",
    "change" : "aldatu",
    "delete" : "ezabatu",
    "Password protected" : "Pasahitzarekin babestuta",
    "Error unsetting expiration date" : "Errorea izan da muga data kentzean",
    "Error setting expiration date" : "Errore bat egon da muga data ezartzean",
    "Sending ..." : "Bidaltzen ...",
    "Email sent" : "Eposta bidalia",
    "Warning" : "Abisua",
    "Edit" : "Editatu",
    "guest" : "gonbidatua",
    "MS Word support (requires openOffice/libreOffice)" : "MS Word (openOffice/libreOffice behar du)",
    "Local" : "Bertakoa",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice zerbitzarian instalatuta dago. Programaren bidea preview_libreoffice_path aukeran zehaztu behar da config.php fitxategian",
    "External" : "Kanpokoa",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice kanpoko zerbitzari batean instalatuta dago zeinak formatu iragazki zerbitzari bat duen",
    "Disabled" : "Ez-gaitua",
    "No MS Word support" : "Ez da MS Word onartzen",
    "scheme://domain.tld[:port]" : "eskema://domain.tld[:port]",
    "Server URL" : "Zerbitzariaren URLa",
    "Apply and test" : "Aplikatu eta probatu",
    "New document" : "Dokumentu berria",
    "Upload (max. %s)" : "Igo (max. %s)",
    "Upload" : "Igo",
    "Save new documents to" : "Gorde dokumentu berriak hemen",
    "Wrong password. Please retry." : "Pasahitz okerra. Saiatu berriro.",
    "Guest %s" : "Gonbidatua %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Lotura hau iraungi da edo ez da inoiz existitu. Mesedez zurekin partekatu zuen pertsonarekin harremanetan jarri zehaztasun gehiago izateko.",
    "Advanced feature-set" : "Ezaugarri aurreratu multzoa",
    "(Unstable)" : "(Ez-egonkorra)"
},
"nplurals=2; plural=(n != 1);");
